<?php

namespace Nelio_AB_Testing\Conversion_Action_Library\WooCommerce_Order_Completed;

defined( 'ABSPATH' ) || exit;

use \add_filter;
use \add_meta_box;

function add_testing_meta_box( $post ) {
	$experiments = get_post_meta( $post->ID, '_nab_experiments_with_page_view', true );
	if ( empty( $experiments ) ) {
		return;
	}//end if

	add_meta_box(
		'nelioab_testing_box',
		'Nelio A/B Testing',
		__NAMESPACE__ . '\render_meta_box',
		'shop_order',
		'side',
		'default'
	);
}//end add_testing_meta_box()
add_action( 'add_meta_boxes_shop_order', __NAMESPACE__ . '\add_testing_meta_box' );

function render_meta_box() {
	$order_id    = get_the_ID();
	$experiments = get_experiments( $order_id );
	$goals       = get_post_meta( $order_id, '_nab_synched_goals', true );

	printf(
		'<p><strong>%s</strong>: %s</p>',
		esc_html_x( 'Status', 'text', 'nelio-ab-testing' ),
		empty( $goals )
			? esc_html_x( 'Not Synched', 'text (order sync status)', 'nelio-ab-testing' )
			: esc_html_x( 'Synched', 'text (order sync status)', 'nelio-ab-testing' )
	);

	printf(
		'<p>%s</p>',
		esc_html_x( 'Tests in which the visitor participated and the variant they saw:', 'text', 'nelio-ab-testing' )
	);
	echo '<ul>';
	foreach ( $experiments as $experiment ) {
		render_experiment( $experiment );
	}//end foreach
	echo '</ul>';
}//end render_meta_box()

function render_experiment( $exp ) {
	$alt = chr( ord( 'A' ) + $exp['alt'] );
	$alt = sprintf(
		/* translators: variant letter (A, B, C, ...) */
		_x( 'variant %s', 'text', 'nelio-ab-testing' ),
		esc_html( $alt )
	);

	$style = 'list-style:disc; margin-left: 1.2em';

	if ( $exp['link'] ) {
		printf(
			'<li style="%s"><a href="%s">%s</a> (%s)</li>',
			esc_attr( $style ),
			esc_url( $exp['link'] ),
			esc_html( $exp['name'] ),
			esc_html( $alt )
		);
	} else {
		printf(
			'<li style="%s">%s (%s)</li>',
			esc_attr( $style ),
			esc_html( $exp['name'] ),
			esc_html( $alt )
		);
	}//end if
}//end render_experiment()

function get_experiments( $order_id ) {
	global $wpdb;

	$exp_alt_map = get_post_meta( $order_id, '_nab_experiments_with_page_view', true );
	$exp_ids     = array_map( '\absint', array_keys( $exp_alt_map ) );

	$experiments = $wpdb->get_results( // phpcs:ignore
		$wpdb->prepare(
			"SELECT ID, post_title, post_status FROM $wpdb->posts p
					WHERE p.post_type = %s AND p.ID IN (%s)",
			'nab_experiment',
			implode( ',', $exp_ids )
		)
	);

	$experiments = array_reduce(
		$experiments,
		function( $carry, $exp ) {
			$carry[ absint( $exp->ID ) ] = array(
				'name'   => $exp->post_title,
				'status' => $exp->post_status,
			);
			return $carry;
		},
		array()
	);

	return array_map(
		function( $id ) use ( &$exp_alt_map, &$experiments ) {
			/* translators: test ID */
			$unknown = _x( 'Test %d is no longer available', 'text', 'nelio-ab-testing' );

			$res = array(
				'id'   => $id,
				'link' => false,
				'name' => sprintf( $unknown, $id ),
				'alt'  => isset( $exp_alt_map[ $id ] ) ? $exp_alt_map[ $id ] : 0,
			);

			if ( isset( $experiments[ $id ] ) ) {
				$exp = $experiments[ $id ];

				$res['name'] = $exp['name'];
				if ( in_array( $exp['status'], array( 'nab_running', 'nab_finished' ), true ) ) {
					$res['link'] = add_query_arg(
						array(
							'page'       => 'nelio-ab-testing-experiment-view',
							'experiment' => $id,
						),
						admin_url( 'admin.php' )
					);
				}//end if
			}//end if

			return $res;
		},
		$exp_ids
	);
}//end get_experiments()
